/*

  Author(s): Ilja V. Ryndin (ryndin@pinebrush.com)

  Start date: *

*/

#ifndef ELEMENTSELECTDIALOG_H
#define ELEMENTSELECTDIALOG_H

#include "parsec_common_qt5_global.h"

#include <pwd.h>
#include <grp.h>
#include <sys/types.h>

#include <QDialog>

class QGroupBox;
class QButtonGroup;
class QListWidget;
class QDialogButtonBox;
class QRadioButton;

namespace ParsecQt5
{
    class PARSEC_COMMON_QT5_EXPORT ElementSelectDialog : public QDialog
    {
    Q_OBJECT

    public:

        enum Mode { UserOnlyMode = 0, GroupOnlyMode = 1, UserAndGroupMode = 2, UserAndGroupAndOtherMode = 3 };
        enum ElementType { NoElementType = 0, UserElementType = 1, GroupElementType = 2, OtherElementType = 3 };

        ElementSelectDialog( const QList<uid_t> &excludedUserId, const QList<gid_t> &excludedGroupId, Mode mode, QWidget *parent = nullptr );
        virtual ~ElementSelectDialog();

        int id();
        ElementType type();
        QString name();
        void setOtherIsEnabled( bool );

    private slots:

        void selectionChanged();
        void rebuildFor( int );

    private:

        void updateEnables();

        Mode m_mode;

        QGroupBox *m_elementListGroupBox;
        QButtonGroup *m_elementButtonGroup;
        QListWidget *m_elementListWidget;
        QDialogButtonBox *m_buttonBox;
        QRadioButton *m_otherRadioButton;

        QPushButton *m_donePushButton;

        QList<uid_t> m_excludedUserIdList;
        QList<gid_t> m_excludedGroupIdList;
    };
}

#endif // ELEMENTSELECTDIALOG_H
